@@ -34,12 +34,14 @@ except ImportError:
 import tencentcloud
 from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
 from tencentcloud.common.exception import TencentCloudSDKException as SDKError
-from tencentcloud.common.http.request import ApiRequest
+from tencentcloud.common.http.request import ApiRequest, ResponsePrettyFormatter
 from tencentcloud.common.http.request import RequestInternal
-from tencentcloud.common.profile.client_profile import ClientProfile
+from tencentcloud.common.profile.client_profile import ClientProfile, RegionBreakerProfile
 from tencentcloud.common.sign import Sign
+from tencentcloud.common.circuit_breaker import CircuitBreaker
+from tencentcloud.common.retry import NoopRetryer
 
-warnings.filterwarnings("ignore")
+warnings.filterwarnings("ignore", module="tencentcloud", category=UserWarning)
 
 _json_content = 'application/json'
 _multipart_content = 'multipart/form-data'
@@ -76,9 +78,19 @@ class AbstractClient(object):
                                   req_timeout=self.profile.httpProfile.reqTimeout,
                                   proxy=self.profile.httpProfile.proxy,
                                   is_http=is_http,
-                                  certification=self.profile.httpProfile.certification)
+                                  certification=self.profile.httpProfile.certification,
+                                  pre_conn_pool_size=self.profile.httpProfile.pre_conn_pool_size)
         if self.profile.httpProfile.keepAlive:
             self.request.set_keep_alive()
+        self.circuit_breaker = None
+        if not self.profile.disable_region_breaker:
+            if self.profile.region_breaker_profile is None:
+                self.profile.region_breaker_profile = RegionBreakerProfile()
+            self.circuit_breaker = CircuitBreaker(self.profile.region_breaker_profile)
+        if self.profile.request_client:
+            self.request_client = self._sdkVersion + "; " + self.profile.request_client
+        else:
+            self.request_client = self._sdkVersion
 
     def _fix_params(self, params):
         if not isinstance(params, (dict,)):
@@ -128,7 +140,7 @@ class AbstractClient(object):
     def _build_req_with_old_signature(self, action, params, req):
         params = copy.deepcopy(self._fix_params(params))
         params['Action'] = action[0].upper() + action[1:]
-        params['RequestClient'] = self._sdkVersion
+        params['RequestClient'] = self.request_client
         params['Nonce'] = random.randint(1, sys.maxsize)
         params['Timestamp'] = int(time.time())
         params['Version'] = self._apiVersion
@@ -177,7 +189,7 @@ class AbstractClient(object):
         timestamp = int(time.time())
         req.header["Host"] = endpoint
         req.header["X-TC-Action"] = action[0].upper() + action[1:]
-        req.header["X-TC-RequestClient"] = self._sdkVersion
+        req.header["X-TC-RequestClient"] = self.request_client
         req.header["X-TC-Timestamp"] = str(timestamp)
         req.header["X-TC-Version"] = self._apiVersion
         if self.profile.unsignedPayload is True:
@@ -268,7 +280,7 @@ class AbstractClient(object):
         timestamp = int(time.time())
         req.header["Host"] = endpoint
         req.header["X-TC-Action"] = action[0].upper() + action[1:]
-        req.header["X-TC-RequestClient"] = self._sdkVersion
+        req.header["X-TC-RequestClient"] = self.request_client
         req.header["X-TC-Timestamp"] = str(timestamp)
         req.header["X-TC-Version"] = self._apiVersion
         if self.profile.unsignedPayload is True:
@@ -317,8 +329,9 @@ class AbstractClient(object):
         return body
 
     def _check_status(self, resp_inter):
-        if resp_inter.status != 200:
-            raise TencentCloudSDKException("ServerNetworkError", resp_inter.data)
+        if resp_inter.status_code != 200:
+            logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp_inter))
+            raise TencentCloudSDKException("ServerNetworkError", resp_inter.content)
 
     def _format_sign_string(self, params):
         formatParam = {}
@@ -338,31 +351,124 @@ class AbstractClient(object):
             endpoint = self._get_service_domain()
         return endpoint
 
-    def _handle_response(self, data):
-        resp = json.loads(data)
-        if "Error" in resp["Response"]:
-            code = resp["Response"]["Error"]["Code"]
-            message = resp["Response"]["Error"]["Message"]
-            reqid = resp["Response"]["RequestId"]
+    def _check_error(self, resp):
+        ct = resp.headers.get('Content-Type')
+        if ct not in ('text/plain', _json_content):
+            return
+
+        data = json.loads(resp.content)
+        if "Error" in data["Response"]:
+            code = data["Response"]["Error"]["Code"]
+            message = data["Response"]["Error"]["Message"]
+            reqid = data["Response"]["RequestId"]
+            logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp))
             raise TencentCloudSDKException(code, message, reqid)
-        if "DeprecatedWarning" in resp["Response"]:
+        if "DeprecatedWarning" in data["Response"]:
             import warnings
             warnings.filterwarnings("default")
-            warnings.warn("This action is deprecated, detail: %s" % resp["Response"]["DeprecatedWarning"],
+            warnings.warn("This action is deprecated, detail: %s" % data["Response"]["DeprecatedWarning"],
                           DeprecationWarning)
 
-    def call(self, action, params, options=None, headers=None):
+    @staticmethod
+    def _process_response_sse(resp):
+        logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp, format_body=False))
+        e = {}
+
+        for line in resp.iter_lines():
+            if not line:
+                yield e
+                e = {}
+                continue
+
+            logger.debug("GetResponse: %s", line)
+            line = line.decode('utf-8')
+
+            # comment
+            if line[0] == ':':
+                continue
+
+            colon_idx = line.find(':')
+            key = line[:colon_idx]
+            val = line[colon_idx + 1:]
+            # If value starts with a U+0020 SPACE character, remove it from value.
+            if val and val[0] == " ":
+                val = val[1:]
+            if key == 'data':
+                # The spec allows for multiple data fields per event, concatenated them with "\n".
+                if 'data' not in e:
+                    e['data'] = val
+                else:
+                    e['data'] += '\n' + val
+            elif key in ('event', 'id'):
+                e[key] = val
+            elif key == 'retry':
+                e[key] = int(val)
+
+    @staticmethod
+    def _process_response_json(resp, resp_type):
+        resp_obj = json.loads(resp.content)["Response"]
+        model = resp_type()
+        model._deserialize(resp_obj)
+        return model
+
+    def _call(self, action, params, options=None, headers=None):
+        if headers is None:
+            headers = {}
+        if not isinstance(headers, dict):
+            raise TencentCloudSDKException("ClientError", "headers must be a dict.")
+        if "x-tc-traceid" not in {k.lower() for k in headers.keys()}:
+            headers["X-TC-TraceId"] = str(uuid.uuid4())
+        if not self.profile.disable_region_breaker:
+            return self._call_with_region_breaker(action, params, options, headers)
         req = RequestInternal(self._get_endpoint(),
                               self.profile.httpProfile.reqMethod,
                               self._requestPath,
                               header=headers)
         self._build_req_inter(action, params, req, options)
 
-        resp_inter = self.request.send_request(req)
-        self._check_status(resp_inter)
-        data = resp_inter.data
-        self._handle_response(data)
-        return data
+        if self.profile.httpProfile.apigw_endpoint:
+            req.host = self.profile.httpProfile.apigw_endpoint
+            req.header["Host"] = req.host
+        return self.request.send_request(req)
+
+    def call(self, action, params, options=None, headers=None):
+
+        def _call_once():
+            resp = self._call(action, params, options, headers)
+            self._check_status(resp)
+            self._check_error(resp)
+            logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp))
+            return resp
+
+        retryer = self.profile.retryer or NoopRetryer()
+        return retryer.send_request(_call_once).content
+
+    def _call_with_region_breaker(self, action, params, options=None, headers=None):
+        endpoint = self._get_endpoint()
+        generation, need_break = self.circuit_breaker.before_requests()
+        if need_break:
+            endpoint = self._service + "." + self.profile.region_breaker_profile.backup_endpoint
+        req = RequestInternal(endpoint,
+                              self.profile.httpProfile.reqMethod,
+                              self._requestPath,
+                              header=headers)
+        self._build_req_inter(action, params, req, options)
+        resp = None
+        try:
+            resp = self.request.send_request(req)
+            self.circuit_breaker.after_requests(generation, True)
+            return resp
+        except TencentCloudSDKException as e:
+            if resp and "RequestId" in resp.content and e.code != "InternalError":
+                self.circuit_breaker.after_requests(generation, True)
+            else:
+                self.circuit_breaker.after_requests(generation, False)
+
+    def call_with_region_breaker(self, action, params, options=None, headers=None):
+        resp = self._call_with_region_breaker(action, params, options, headers)
+        self._check_status(resp)
+        self._check_error(resp)
+        return resp.content
 
     def call_octet_stream(self, action, headers, body):
         """
@@ -387,20 +493,16 @@ class AbstractClient(object):
 
         req = RequestInternal(self._get_endpoint(),
                               self.profile.httpProfile.reqMethod,
-                              self._requestPath)
-        for key in headers:
-            req.header[key] = headers[key]
+                              self._requestPath,
+                              header=headers)
         req.data = body
         options = {"IsOctetStream": True}
         self._build_req_inter(action, None, req, options)
 
         resp = self.request.send_request(req)
         self._check_status(resp)
-        data = resp.data
-        self._handle_response(data)
-
-        json_rsp = json.loads(data)
-        return json_rsp
+        self._check_error(resp)
+        return json.loads(resp.content)
 
     def call_json(self, action, params, headers=None, options=None):
         """
@@ -415,9 +517,44 @@ class AbstractClient(object):
         :type options: dict
         :param options: request options, like {"SkipSign": False, "IsMultipart": False, "IsOctetStream": False, "BinaryParams": []}
         """
-        body = self.call(action, params, options, headers)
-        response = json.loads(body)
-        return response
+
+        def _call_once():
+            resp = self._call(action, params, options, headers)
+            self._check_status(resp)
+            self._check_error(resp)
+            logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp))
+            return resp
+
+        retryer = self.profile.retryer or NoopRetryer()
+        return json.loads(retryer.send_request(_call_once).content)
+
+    def call_sse(self, action, params, headers=None, options=None):
+        def _call_once():
+            resp = self._call(action, params, options, headers)
+            self._check_status(resp)
+            self._check_error(resp)
+            return resp
+
+        retryer = self.profile.retryer or NoopRetryer()
+        return self._process_response_sse(retryer.send_request(_call_once))
+
+    def _call_and_deserialize(self, action, params, resp_type, headers=None, options=None):
+        def _call_once():
+            resp = self._call(action, params, options, headers)
+            self._check_status(resp)
+            self._check_error(resp)
+            return resp
+
+        retryer = self.profile.retryer or NoopRetryer()
+        return self._process_response(retryer.send_request(_call_once), resp_type)
+
+    def _process_response(self, resp, resp_type):
+        if resp.headers.get('Content-Type') == "text/event-stream":
+            logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp, format_body=False))
+            return self._process_response_sse(resp)
+
+        logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp))
+        return self._process_response_json(resp, resp_type)
 
     def set_stream_logger(self, stream=None, level=logging.DEBUG, log_format=None):
         """
@@ -454,7 +591,7 @@ class AbstractClient(object):
         log = logging.getLogger(LOGGER_NAME)
         log.setLevel(level)
         mb = 1024 * 1024
-        fh = logging.handlers.RotatingFileHandler(file_path, maxBytes=512*mb, backupCount=10)
+        fh = logging.handlers.RotatingFileHandler(file_path, maxBytes=512 * mb, backupCount=10)
         fh.setLevel(level)
         if log_format is None:
             log_format = self.FMT
