@@ -73,7 +73,9 @@ class LkeClient(AbstractClient):
 
 
     def ConvertDocument(self, request):
-        """接口支持图片和PDF转可编辑word格式文件，将文件中的图片、文本、表格等元素识别，并根据位置进行还原。
+        """产品规划
+
+        接口支持图片和PDF转可编辑word格式文件，将文件中的图片、文本、表格等元素识别，并根据位置进行还原。
 
         :param request: Request instance for ConvertDocument.
         :type request: :class:`tencentcloud.lke.v20231130.models.ConvertDocumentRequest`
@@ -164,6 +166,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateDocCate(self, request):
+        """创建Doc分类
+
+        :param request: Request instance for CreateDocCate.
+        :type request: :class:`tencentcloud.lke.v20231130.models.CreateDocCateRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.CreateDocCateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateDocCate", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateDocCateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateQA(self, request):
         """录入问答
 
@@ -282,6 +307,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateVar(self, request):
+        """创建变量
+
+        :param request: Request instance for CreateVar.
+        :type request: :class:`tencentcloud.lke.v20231130.models.CreateVarRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.CreateVarResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateVar", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateVarResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteApp(self, request):
         """删除应用
 
@@ -351,6 +399,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteDocCate(self, request):
+        """Doc分类删除
+
+        :param request: Request instance for DeleteDocCate.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DeleteDocCateRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DeleteDocCateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteDocCate", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteDocCateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteQA(self, request):
         """删除问答
 
@@ -466,6 +537,75 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeCallStatsGraph(self, request):
+        """接口调用折线图
+
+        :param request: Request instance for DescribeCallStatsGraph.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeCallStatsGraphRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeCallStatsGraphResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCallStatsGraph", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCallStatsGraphResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeConcurrencyUsage(self, request):
+        """并发调用响应
+
+        :param request: Request instance for DescribeConcurrencyUsage.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeConcurrencyUsageRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeConcurrencyUsageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeConcurrencyUsage", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeConcurrencyUsageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeConcurrencyUsageGraph(self, request):
+        """并发调用折线图
+
+        :param request: Request instance for DescribeConcurrencyUsageGraph.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeConcurrencyUsageGraphRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeConcurrencyUsageGraphResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeConcurrencyUsageGraph", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeConcurrencyUsageGraphResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeCorp(self, request):
         """企业详情
 
@@ -512,6 +652,52 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeKnowledgeUsage(self, request):
+        """查询知识库用量
+
+        :param request: Request instance for DescribeKnowledgeUsage.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeKnowledgeUsageRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeKnowledgeUsageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeKnowledgeUsage", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeKnowledgeUsageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeKnowledgeUsagePieGraph(self, request):
+        """查询企业知识库容量饼图
+
+        :param request: Request instance for DescribeKnowledgeUsagePieGraph.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeKnowledgeUsagePieGraphRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeKnowledgeUsagePieGraphResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeKnowledgeUsagePieGraph", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeKnowledgeUsagePieGraphResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeQA(self, request):
         """问答详情
 
@@ -627,6 +813,52 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeSearchStatsGraph(self, request):
+        """查询搜索服务调用折线图
+
+        :param request: Request instance for DescribeSearchStatsGraph.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeSearchStatsGraphRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeSearchStatsGraphResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSearchStatsGraph", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSearchStatsGraphResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeSegments(self, request):
+        """获取片段详情
+
+        :param request: Request instance for DescribeSegments.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeSegmentsRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeSegmentsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSegments", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSegmentsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeStorageCredential(self, request):
         """获取文件上传临时密钥
 
@@ -650,6 +882,52 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeTokenUsage(self, request):
+        """接口调用token详情
+
+        :param request: Request instance for DescribeTokenUsage.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeTokenUsageRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeTokenUsageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTokenUsage", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeTokenUsageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeTokenUsageGraph(self, request):
+        """接口调用token折线图
+
+        :param request: Request instance for DescribeTokenUsageGraph.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeTokenUsageGraphRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeTokenUsageGraphResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTokenUsageGraph", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeTokenUsageGraphResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeUnsatisfiedReplyContext(self, request):
         """获取不满意回复上下文
 
@@ -905,7 +1183,7 @@ class LkeClient(AbstractClient):
 
 
     def GetMsgRecord(self, request):
-        """获取推荐问题
+        """获取聊天历史请求
 
         :param request: Request instance for GetMsgRecord.
         :type request: :class:`tencentcloud.lke.v20231130.models.GetMsgRecordRequest`
@@ -973,6 +1251,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def GetVarList(self, request):
+        """查询自定义变量列表
+
+        :param request: Request instance for GetVarList.
+        :type request: :class:`tencentcloud.lke.v20231130.models.GetVarListRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.GetVarListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetVarList", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetVarListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def GetWsToken(self, request):
         """获取ws token
 
@@ -996,6 +1297,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def GroupDoc(self, request):
+        """Doc分组
+
+        :param request: Request instance for GroupDoc.
+        :type request: :class:`tencentcloud.lke.v20231130.models.GroupDocRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.GroupDocResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GroupDoc", params, headers=headers)
+            response = json.loads(body)
+            model = models.GroupDocResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def GroupQA(self, request):
         """QA分组
 
@@ -1111,6 +1435,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ListAppKnowledgeDetail(self, request):
+        """列表查询知识库容量详情
+
+        :param request: Request instance for ListAppKnowledgeDetail.
+        :type request: :class:`tencentcloud.lke.v20231130.models.ListAppKnowledgeDetailRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.ListAppKnowledgeDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListAppKnowledgeDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListAppKnowledgeDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ListAttributeLabel(self, request):
         """查询属性标签列表
 
@@ -1157,6 +1504,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ListDocCate(self, request):
+        """获取Doc分类
+
+        :param request: Request instance for ListDocCate.
+        :type request: :class:`tencentcloud.lke.v20231130.models.ListDocCateRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.ListDocCateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListDocCate", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListDocCateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ListModel(self, request):
         """获取模型列表
 
@@ -1410,6 +1780,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ListUsageCallDetail(self, request):
+        """列表查询单次调用明细
+
+        :param request: Request instance for ListUsageCallDetail.
+        :type request: :class:`tencentcloud.lke.v20231130.models.ListUsageCallDetailRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.ListUsageCallDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListUsageCallDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListUsageCallDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyApp(self, request):
         """修改应用请求结构体
 
@@ -1502,6 +1895,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyDocCate(self, request):
+        """修改Doc分类
+
+        :param request: Request instance for ModifyDocCate.
+        :type request: :class:`tencentcloud.lke.v20231130.models.ModifyDocCateRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.ModifyDocCateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyDocCate", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyDocCateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyQA(self, request):
         """更新问答
 
@@ -1595,7 +2011,9 @@ class LkeClient(AbstractClient):
 
 
     def ParseDoc(self, request):
-        """接口即将下线，请切换使用新接口：[文档解析](https://cloud.tencent.com/document/product/1759/107504)
+        """接口已迁移到新接口了，无调用量
+
+        接口即将下线，请切换使用新接口：[文档解析](https://cloud.tencent.com/document/product/1759/107504)
 
         :param request: Request instance for ParseDoc.
         :type request: :class:`tencentcloud.lke.v20231130.models.ParseDocRequest`
@@ -1618,7 +2036,9 @@ class LkeClient(AbstractClient):
 
 
     def QueryParseDocResult(self, request):
-        """查询文档解析结果。该接口需开通文档解析原子能力后调用。文档解析原子能力内测中，如有需要请联系架构师或[联系客服](https://cloud.tencent.com/act/event/Online_service) 。
+        """接口已迁移到新接口了，无调用量
+
+        查询文档解析结果。该接口需开通文档解析原子能力后调用。文档解析原子能力内测中，如有需要请联系架构师或[联系客服](https://cloud.tencent.com/act/event/Online_service) 。
 
         :param request: Request instance for QueryParseDocResult.
         :type request: :class:`tencentcloud.lke.v20231130.models.QueryParseDocResultRequest`
@@ -1665,7 +2085,7 @@ class LkeClient(AbstractClient):
 
 
     def RateMsgRecord(self, request):
-        """是否意图转人工
+        """点赞点踩消息
 
         :param request: Request instance for RateMsgRecord.
         :type request: :class:`tencentcloud.lke.v20231130.models.RateMsgRecordRequest`
@@ -1712,6 +2132,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RenameDoc(self, request):
+        """文档重命名
+
+        :param request: Request instance for RenameDoc.
+        :type request: :class:`tencentcloud.lke.v20231130.models.RenameDocRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.RenameDocResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RenameDoc", params, headers=headers)
+            response = json.loads(body)
+            model = models.RenameDocResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ResetSession(self, request):
         """重置会话
 
@@ -1804,6 +2247,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RunReRank(self, request):
+        """基于知识引擎精调模型技术的rerank模型，支持对多路召回的结果进行重排序，根据query与切片内容的相关性，按分数由高到低对切片进行排序，并输出对应的打分结果。
+
+        :param request: Request instance for RunReRank.
+        :type request: :class:`tencentcloud.lke.v20231130.models.RunReRankRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.RunReRankResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RunReRank", params, headers=headers)
+            response = json.loads(body)
+            model = models.RunReRankResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def SaveDoc(self, request):
         """保存文档
 
